@@ -1,14 +1,12 @@
 package Pcore::Util::URI::ssh;    ## no critic qw[NamingConventions::Capitalization]
 
-use Pcore qw[-class];
+use Pcore -class;
 
 extends qw[Pcore::Util::URI];
 
 has '+is_secure'    => ( default => 1 );
 has '+default_port' => ( default => 22 );
 
-no Pcore;
-
 1;
 __END__
 =pod
